(function( $ ) {
	'use strict';

	if(typeof postapi_data === 'undefined')
		return;

	if(typeof postapi_data['token'] === 'undefined' || postapi_data['token'] == '')
		return;

	var promo_text = '<small class="clearfix postapi_txt">Pašto kodų integracija - <a href="https://postapi.lt" target="_blank">PostAPI.lt</a></small>';
	var address_xhr;
	var address_field = $('input#billing_address_1');
	var city_field = $('input#billing_city');
	var country_field = $('#billing_country');
	var postcode_field = $('input#billing_postcode');
	var municipality_field = $('input#billing_state');

	// if we cannot find address field or autocomplete is not available - skip whole script
	if(address_field.length === 0 || typeof address_field.autocomplete !== 'function') {
		return;
	}

	// promo text on load
	if(country_field.length === 1 && country_field.val().toLowerCase() === 'lt'){
		$('.postapi_txt').remove();
		if (postapi_data['is_free'])
			postcode_field.after(promo_text);
	}

	// promo text on country change
	country_field.change(function (){
		if (country_field.val().toLowerCase() == 'lt' && postapi_data['is_free']) {
			if ($('.postapi_txt').length == 0)
				postcode_field.after(promo_text);
		}
		else
		{
			if ($('.postapi_txt').length == 1)
				$('.postapi_txt').remove();
		}
	});

	address_field.autocomplete({
		minLength: 4,
		delay: 300,
		source: function(request, response)
		{
			var element = this.element;
			$(element).addClass('loading');

			// disabling ajax when country not lithuania
			if(country_field.length === 1 && country_field.val().toLowerCase() !== 'lt')
				return;

			// request args
			var request_args = {
				token: postapi_data['token'],
				autocomplete: 1,
				wide_number: 0,
			};

			// request data
			var request_data = $.extend(request_args, {address: $.trim(request.term)});

			// abort previous request
			if(address_xhr){
				address_xhr.abort();
			}

			address_xhr = $.ajax({
				url: postapi_data['api_url'],
				dataType: 'json',
				crossDomain: true,
				data: request_data,
				success: function(resp){
					var r = [];
					if ( !resp.success ){
						response(r);
						return;
					}

					for (var i = 0, l = resp.data.length; i < l; i++) {
						var t = '';
						var address = resp.data[i].address;

						if (address === '') {
							t = (resp.data[i].city);
						} else {
							if (typeof resp.address_apartment != "undefined") {
								address += '-' + resp.address_apartment;
							}

							t = (address + ', ' + resp.data[i].city);
						}

						r.push({
							label: t + ', ' + resp.data[i].postcode,
							value: address,
							address: address,
							city: resp.data[i].city,
							postcode: resp.data[i].postcode,
							municipality: resp.data[i].municipality
						});
						response(r);
					}

				},
				error: function(){
					response([]);
				},
				complete: function(){
					$(element).removeClass('loading');
				}
			});
		},
		select: function(event, ui){
			address_field.val(ui.item.address);
			city_field.val(ui.item.city);
			municipality_field.val(ui.item.municipality);
			postcode_field.val(postapi_data['prefix'] + ui.item.postcode);

			$(document.body).trigger('update_checkout');
		}
	});

})( jQuery );
